Star

Struct Star 

#[repr(transparent)]
pub struct Star { pub spans: [Span; 1], }
*

Usage: multiplication, dereference, raw pointers, macro Kleene matcher, use wildcards.

Don’t try to remember the name of this type — use the Token! macro instead.

Fields

spans: [Span; 1]