#[repr(transparent)]pub struct ArraySet<T, const N: usize>(pub [T; N]);Expand description
An array wrapper representing a fixed-size set (modulo duplicate items).
Tuple Fields
0: [T; N]Trait Implementations
Sourceimpl<T, const N: usize> Collection for ArraySet<T, N>
impl<T, const N: usize> Collection for ArraySet<T, N>
Sourceimpl<T, const N: usize> CollectionMut for ArraySet<T, N>
impl<T, const N: usize> CollectionMut for ArraySet<T, N>
Sourcetype ItemMut<'a> = &'a mut T
where
ArraySet<T, N>: 'a
type ItemMut<'a> = &'a mut T where ArraySet<T, N>: 'a
Type of mutable references to items of the collection.
Sourcefn upcast_item_mut<'short, 'long>(
r: <ArraySet<T, N> as CollectionMut>::ItemMut<'long>,
) -> <ArraySet<T, N> as CollectionMut>::ItemMut<'short>where
'long: 'short,
ArraySet<T, N>: 'long,
fn upcast_item_mut<'short, 'long>(
r: <ArraySet<T, N> as CollectionMut>::ItemMut<'long>,
) -> <ArraySet<T, N> as CollectionMut>::ItemMut<'short>where
'long: 'short,
ArraySet<T, N>: 'long,
Changes an item mutable reference into a shorter lived mutable reference. Read more
Sourceimpl<T, const N: usize> CollectionRef for ArraySet<T, N>
impl<T, const N: usize> CollectionRef for ArraySet<T, N>
Sourcetype ItemRef<'a> = &'a T
where
ArraySet<T, N>: 'a
type ItemRef<'a> = &'a T where ArraySet<T, N>: 'a
Type of references to items of the collection.
Sourcefn upcast_item_ref<'short, 'long>(
r: <ArraySet<T, N> as CollectionRef>::ItemRef<'long>,
) -> <ArraySet<T, N> as CollectionRef>::ItemRef<'short>where
'long: 'short,
ArraySet<T, N>: 'long,
fn upcast_item_ref<'short, 'long>(
r: <ArraySet<T, N> as CollectionRef>::ItemRef<'long>,
) -> <ArraySet<T, N> as CollectionRef>::ItemRef<'short>where
'long: 'short,
ArraySet<T, N>: 'long,
Changes an item reference into a shorter lived reference. Read more
Sourceimpl<T, const N: usize> IntoIterator for ArraySet<T, N>
impl<T, const N: usize> IntoIterator for ArraySet<T, N>
Sourceimpl<T, const N: usize> Ord for ArraySet<T, N>where
T: Ord,
impl<T, const N: usize> Ord for ArraySet<T, N>where
T: Ord,
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T, const N: usize> PartialOrd for ArraySet<T, N>where
T: PartialOrd,
impl<T, const N: usize> PartialOrd for ArraySet<T, N>where
T: PartialOrd,
Sourceimpl<T, const N: usize> SimpleCollectionRef for ArraySet<T, N>
impl<T, const N: usize> SimpleCollectionRef for ArraySet<T, N>
fn into_ref<'r>(
r: <ArraySet<T, N> as CollectionRef>::ItemRef<'r>,
) -> &'r <ArraySet<T, N> as Collection>::Itemwhere
ArraySet<T, N>: 'r,
impl<T, const N: usize> Copy for ArraySet<T, N>where
T: Copy,
impl<T, const N: usize> Eq for ArraySet<T, N>where
T: Eq,
impl<T, const N: usize> StructuralPartialEq for ArraySet<T, N>