pub struct OptionMap<K, V>(pub Option<(K, V)>);Expand description
A key-value entry wrapper around Option<(K, V)> representing a singleton or empty map.
Tuple Fields
0: Option<(K, V)>Trait Implementations
Sourceimpl<K, V> Collection for OptionMap<K, V>
impl<K, V> Collection for OptionMap<K, V>
Sourceimpl<K, V> CollectionMut for OptionMap<K, V>
impl<K, V> CollectionMut for OptionMap<K, V>
Sourcetype ItemMut<'a> = &'a mut <OptionMap<K, V> as Collection>::Item
where
OptionMap<K, V>: 'a
type ItemMut<'a> = &'a mut <OptionMap<K, V> as Collection>::Item where OptionMap<K, V>: 'a
Type of mutable references to items of the collection.
Sourcefn upcast_item_mut<'short, 'long>(
r: <OptionMap<K, V> as CollectionMut>::ItemMut<'long>,
) -> <OptionMap<K, V> as CollectionMut>::ItemMut<'short>where
'long: 'short,
OptionMap<K, V>: 'long,
fn upcast_item_mut<'short, 'long>(
r: <OptionMap<K, V> as CollectionMut>::ItemMut<'long>,
) -> <OptionMap<K, V> as CollectionMut>::ItemMut<'short>where
'long: 'short,
OptionMap<K, V>: 'long,
Changes an item mutable reference into a shorter lived mutable reference. Read more
Sourceimpl<K, V> CollectionRef for OptionMap<K, V>
impl<K, V> CollectionRef for OptionMap<K, V>
Sourcetype ItemRef<'a> = &'a <OptionMap<K, V> as Collection>::Item
where
OptionMap<K, V>: 'a
type ItemRef<'a> = &'a <OptionMap<K, V> as Collection>::Item where OptionMap<K, V>: 'a
Type of references to items of the collection.
Sourcefn upcast_item_ref<'short, 'long>(
r: <OptionMap<K, V> as CollectionRef>::ItemRef<'long>,
) -> <OptionMap<K, V> as CollectionRef>::ItemRef<'short>where
'long: 'short,
OptionMap<K, V>: 'long,
fn upcast_item_ref<'short, 'long>(
r: <OptionMap<K, V> as CollectionRef>::ItemRef<'long>,
) -> <OptionMap<K, V> as CollectionRef>::ItemRef<'short>where
'long: 'short,
OptionMap<K, V>: 'long,
Changes an item reference into a shorter lived reference. Read more
Sourceimpl<'de, K, V> Deserialize<'de> for OptionMap<K, V>where
K: Deserialize<'de>,
V: Deserialize<'de>,
impl<'de, K, V> Deserialize<'de> for OptionMap<K, V>where
K: Deserialize<'de>,
V: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OptionMap<K, V>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OptionMap<K, V>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, Q, K, V> GetKeyValue<&'a Q> for OptionMap<K, V>
impl<'a, Q, K, V> GetKeyValue<&'a Q> for OptionMap<K, V>
Sourceimpl<'a, Q, K, V> GetKeyValueMut<&'a Q> for OptionMap<K, V>
impl<'a, Q, K, V> GetKeyValueMut<&'a Q> for OptionMap<K, V>
Sourceimpl<K, V> IntoIterator for OptionMap<K, V>
impl<K, V> IntoIterator for OptionMap<K, V>
Sourceimpl<K, V> KeyedRef for OptionMap<K, V>
impl<K, V> KeyedRef for OptionMap<K, V>
Sourceimpl<K, V> MapIterMut for OptionMap<K, V>
impl<K, V> MapIterMut for OptionMap<K, V>
Sourceimpl<K, OldVal> MapMapValues<OldVal> for OptionMap<K, OldVal>
impl<K, OldVal> MapMapValues<OldVal> for OptionMap<K, OldVal>
Sourcetype MapValue<NewVal> = OptionMap<K, NewVal>
type MapValue<NewVal> = OptionMap<K, NewVal>
Output type, should be
Self but with OldVal replaced with NewVal.Sourcefn map_values<NewVal, MapFn>(
self,
map_fn: MapFn,
) -> <OptionMap<K, OldVal> as MapMapValues<OldVal>>::MapValue<NewVal>where
MapFn: FnMut(OldVal) -> NewVal,
fn map_values<NewVal, MapFn>(
self,
map_fn: MapFn,
) -> <OptionMap<K, OldVal> as MapMapValues<OldVal>>::MapValue<NewVal>where
MapFn: FnMut(OldVal) -> NewVal,
Map the values into using the
map_fn.Sourceimpl<K, V> Ord for OptionMap<K, V>
impl<K, V> Ord for OptionMap<K, V>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<K, V> PartialOrd for OptionMap<K, V>where
K: PartialOrd,
V: PartialOrd,
impl<K, V> PartialOrd for OptionMap<K, V>where
K: PartialOrd,
V: PartialOrd,
Sourceimpl<K, V> Serialize for OptionMap<K, V>
impl<K, V> Serialize for OptionMap<K, V>
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl<K, V> SimpleCollectionRef for OptionMap<K, V>
impl<K, V> SimpleCollectionRef for OptionMap<K, V>
fn into_ref<'r>(
r: <OptionMap<K, V> as CollectionRef>::ItemRef<'r>,
) -> &'r <OptionMap<K, V> as Collection>::Itemwhere
OptionMap<K, V>: 'r,
Sourceimpl<K, V> SimpleKeyedRef for OptionMap<K, V>
impl<K, V> SimpleKeyedRef for OptionMap<K, V>
impl<K, V> Copy for OptionMap<K, V>
impl<K, V> Eq for OptionMap<K, V>
impl<K, V> StructuralPartialEq for OptionMap<K, V>